@@ -25,6 +25,7 @@ Almost all the work is done in `process_orcaflex`, the basic steps are:
 
 
 """
+import platform
 import queue
 import threading
 import time
@@ -34,7 +35,7 @@ from random import randint
 from time import sleep
 from typing import Mapping, Sequence, Union, Tuple
 
-from qalx_orcaflex.core import QalxSmartStaticsFailed
+from qalx_orcaflex.core import QalxSmartStaticsError
 
 try:  # we build the docs on linux and this won't work...
     import OrcFxAPI
@@ -54,6 +55,7 @@ from qalx_orcaflex.data_models import (
     RangeGraph,
     ModelInfo,
     ModelView,
+    JobState,
 )
 from qalx_orcaflex.helpers import (
     nice_time,
@@ -85,7 +87,15 @@ def begin_orcaflex(job):
     pass
 
 
-def preprocess_orcaflex(job):
+def preprocess_orcaflex(job: QalxJob):
+    job.entity["meta"]["state"] = OrcaFlexJobState(
+        state=JobState.PRE_PROCESSING.value
+    ).__dict__
+    job.entity["meta"]["bot_host"] = {
+        "node": platform.node(),
+        "platform": platform.platform(),
+    }
+    job.save_entity()
     options = job.entity.get_item_data("job_options")
     if options:
         job.options = OrcaFlexJobOptions(**options)
@@ -94,23 +104,20 @@ def preprocess_orcaflex(job):
     job.warnings = job.add_item_data(
         "warnings", data={"warning_text": []}, meta={"_class": "orcaflex.warnings"}
     )
-    # job.state = job.add_item_data("state", data={"state": "Pre-processing"})
-    job.entity["meta"]["state"] = OrcaFlexJobState(state="preprocessing").__dict__
-    job.save_entity()
 
 
 # DEV_NOTE: this function was written a long time ago using a functional approach, as it has grown it probably should
 # have been converted to a more object-oriented approach. One day maybe we will get there.
 def process_orcaflex(job: QalxJob) -> None:
-    ofx = OrcaFlexJob(
-        **job.entity["items"]
-    )  # unpack the raw Set into our pre-defined model
-
     def update_job_state(state_dict: Mapping) -> None:
         """update the state and save the set"""
         job.entity["meta"]["state"] = OrcaFlexJobState(**state_dict).__dict__
         job.save_entity()
 
+    update_job_state({"state": JobState.PROCESSING.value})
+    ofx = OrcaFlexJob(
+        **job.entity["items"]
+    )  # unpack the raw Set into our pre-defined model
     update_queue = queue.Queue()
 
     def update_job_progress() -> None:
@@ -178,12 +185,12 @@ def process_orcaflex(job: QalxJob) -> None:
             kill_signal = ofx.kill_signal
             if kill_signal["data"].get("KILL BOT"):
                 job.publish_status("Bot kill signal sent", kill_signal["data"])
-                update_job_state({"state": "User cancelled"})
+                update_job_state({"state": JobState.USER_CANCELLED.value})
                 job.terminate()
                 return False
             if kill_signal["data"].get("KILL JOB"):
                 job.publish_status("Job kill signal sent", kill_signal["data"])
-                update_job_state({"state": "User cancelled"})
+                update_job_state({"state": JobState.USER_CANCELLED.value})
                 return False
 
     def report_statics(model: OrcFxAPI.Model, progress: str) -> None:
@@ -204,10 +211,10 @@ def process_orcaflex(job: QalxJob) -> None:
         update_queue.put(pp)
 
     def report_error(error: str):
-        update_job_state({"state": "Error", "error": error})
+        update_job_state({"state": JobState.ERROR.value, "error": error})
 
     def try_statics(model: OrcFxAPI.Model) -> bool:
-        update_job_state({"state": "Running statics"})
+        update_job_state({"state": JobState.RUNNING_STATICS.value})
         statics = {}  # we save info about how well statics went
 
         def save_statics_data():
@@ -219,7 +226,7 @@ def process_orcaflex(job: QalxJob) -> None:
                 solved_model(
                     model, job.options.max_search_attempts
                 )  # solves with search if required
-            except QalxSmartStaticsFailed as err:
+            except QalxSmartStaticsError:
                 fn = f"{job.entity['meta']['case_name']}_FAILED_SS.dat"
                 ff = job.session.item.add(
                     source=BytesIO(model.SaveDataMem()),
@@ -227,8 +234,8 @@ def process_orcaflex(job: QalxJob) -> None:
                     meta={"_class": "orcaflex.failed_statics"},
                 )
                 job.entity["items"]["failed_statics"] = ff
-                job.save_entity()
-                raise err
+                update_job_state({"state": JobState.STATICS_FAILED.value})
+                return False
             end = time.time()
             statics["time_to_solve"] = end - start
             statics["solves"] = True
@@ -248,7 +255,7 @@ def process_orcaflex(job: QalxJob) -> None:
             return False
 
     def try_dynamics(model: OrcFxAPI.Model) -> bool:
-        update_job_state({"state": "Running dynamics"})
+        update_job_state({"state": JobState.RUNNING_DYNAMICS.value})
         success = False  # we might need to have a few goes at getting a licence
         while not success:
             try:
@@ -270,10 +277,9 @@ def process_orcaflex(job: QalxJob) -> None:
 
     def try_save_sim(model: OrcFxAPI.Model) -> Tuple[bool, Union[None, str]]:
         """try to save the simulation data to qalx"""
-        update_job_state({"state": "Saving simulation"})
+        update_job_state({"state": JobState.SAVING_SIMULATION.value})
         try:
             model_bytes = model.SaveSimulationMem()
-            update_job_state({"state": "Uploading simulation"})
             sim_name = f"{job.entity['meta']['case_name']}.sim"
             job.entity["items"]["simulation_file"] = job.session.item.add(
                 source=BytesIO(model_bytes),
@@ -281,7 +287,7 @@ def process_orcaflex(job: QalxJob) -> None:
                 meta={"_class": "orcaflex.simulation_file"},
             )
             job.save_entity()
-            update_job_state({"state": "Simulation uploaded"})
+            update_job_state({"state": JobState.SIMULATION_SAVED.value})
             return True, None  # worked with no errors
         except Exception as err:
             msg = """Failed to save a simulation:\n\n""" + str(err)
@@ -297,7 +303,7 @@ def process_orcaflex(job: QalxJob) -> None:
         # TODO: use multiple result specification - requires grouping  the results
         #  first by object, period and
         #  object extra
-        update_job_state({"state": "Extracting results"})
+        update_job_state({"state": JobState.EXTRACTING_RESULTS.value})
         job.log.debug(ofx.results)
         for res_n, (_, result_guid) in enumerate(
             ofx.results["data"].items()
@@ -390,7 +396,7 @@ def process_orcaflex(job: QalxJob) -> None:
                 msg = f"Failed to extract result with guid {result_guid}:\n\n{err}"
                 job.log.error(msg + "\n\n" + traceback.format_exc())
                 update_job_warnings([msg])
-        update_job_state({"state": "Extracted"})
+        update_job_state({"state": JobState.RESULTS_EXTRACTED.value})
 
     def extract_load_case_info(model: OrcFxAPI.Model) -> None:
         """extracts load case information"""
@@ -430,21 +436,29 @@ def process_orcaflex(job: QalxJob) -> None:
             ] = mvi.guid  # make a mapping of saved view name to guid of the save data
 
         if ofx.model_views:  # we have some pre-defined views in the OrcaFlexJob
+            update_job_state({"state": JobState.EXTRACTING_MODEL_VIEWS.value})
             for mv_name, mv_raw in ofx.model_views["data"].items():
                 try:
                     extract_view(mv_raw)
                 except Exception as err:
                     update_job_warnings([f"{mv_name} failed. Reason\n {str(err)}"])
 
-        for _, tags in get_tags(
-            model, lambda t: t.startswith("mv__"), True
-        ).items():  # get all the views defined in the model file
-            for tag, data in tags.items():
-                data["ViewName"] = tag.split("__")[-1]
-                try:
-                    extract_view(data)
-                except Exception as err:
-                    update_job_warnings([f"{tag} failed. Reason\n {str(err)}"])
+        mv_tags = get_tags(model, lambda t: t.startswith("mv__"), True)
+        if mv_tags:
+            flag_state = False
+            for _, tags in mv_tags.items():
+                # get all the views defined in the model file
+                for tag, data in tags.items():
+                    if flag_state is False:
+                        update_job_state(
+                            {"state": JobState.EXTRACTING_MODEL_VIEWS.value}
+                        )
+                        flag_state = True
+                    data["ViewName"] = tag.split("__")[-1]
+                    try:
+                        extract_view(data)
+                    except Exception as err:
+                        update_job_warnings([f"{tag} failed. Reason\n {str(err)}"])
 
         if (
             saved_views
@@ -453,13 +467,12 @@ def process_orcaflex(job: QalxJob) -> None:
                 data=saved_views, meta={"_class": "orcaflex.saved_views"}
             )
             job.entity["items"]["saved_views"] = svi
-            job.save_entity()
+            update_job_state({"state": JobState.MODEL_VIEWS_EXTRACTED.value})
 
     # THE FUNCTION BEGINS HERE AND CALLS ABOVE FUNCTIONS AS IT GOES (Not great.)
-
+    update_job_state({"state": JobState.LOADING_MODEL_DATA.value})
     model = load_model_data(ofx, job.options)  # load the model
 
-    update_job_state({"state": "Running"})
     if job.options.record_progress:  # set the handlers
         model.dynamicsProgressHandler = report_dynamics
         model.staticsProgressHandler = report_statics
@@ -467,7 +480,7 @@ def process_orcaflex(job: QalxJob) -> None:
     # TODO: #2750-include-model-deltas-in-job
 
     ram_per_core = (
-        (psutil.virtual_memory().total / 1024) * 0.90 / psutil.cpu_count()
+        (psutil.virtual_memory().available / 1024) * 0.90 / psutil.cpu_count()
     )  # in MB
 
     if model_simulation_size(model) > ram_per_core:  # set the right logging
@@ -480,7 +493,6 @@ def process_orcaflex(job: QalxJob) -> None:
         job.entity["meta"]["processing_complete"] = True
         return
 
-    update_job_state({"state": "Dynamics complete"})
     if job.options.save_simulation:  # try to save the sim
         worked, warning = try_save_sim(model)
         if not worked:
@@ -496,7 +508,9 @@ def process_orcaflex(job: QalxJob) -> None:
         extract_model_views(model)
 
     if ofx.model_videos:
+        update_job_state({"state": JobState.EXTRACTING_MODEL_VIDEOS.value})
         video_extractor.extract_model_videos(job=job, ofx=ofx, model=model)
+        update_job_state({"state": JobState.MODEL_VIDEOS_EXTRACTED.value})
 
     if (
         str(model.state) == "SimulationStoppedUnstable"
@@ -505,7 +519,7 @@ def process_orcaflex(job: QalxJob) -> None:
             model.simulationTimeStatus.CurrentTime
         )
         update_job_warnings([msg])
-        update_job_state({"state": "Simulation unstable"})
+        update_job_state({"state": JobState.SIMULATION_UNSTABLE.value})
 
     # this allows `postprocessing_function` to access model data
     job.context["model"] = model
