@@ -4,13 +4,14 @@ from dataclasses import asdict
 from os import PathLike
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import Union, Sequence, Mapping
+from typing import Union, Sequence, Mapping, List
 
 import pyqalx
 from OrcFxAPI import Model
 from pyqalx import QalxSession, Item, Group, Set
 
 from qalx_orcaflex import data_models
+from qalx_orcaflex.data_models import JobState
 from qalx_orcaflex.helpers import (
     data_file_paths,
     required_results_from_yaml,
@@ -568,6 +569,36 @@ class QalxOrcaFlex(pyqalx.QalxSession):
         Set.add_to_queue(payload=video_job, queue=video_queue)
         return video_job.guid
 
+    def jobs_by_state(
+        self,
+        batch_name,
+        include: List[JobState] = None,
+        exclude: List[JobState] = None,
+        unpack=True,
+    ):
+        if (include is not None) and (exclude is not None):
+            raise QalxOrcaFlexError("Only include or exclude can be supplied")
+        elif include:
+            includes = [i.value for i in include]
+            jobs_q = self.set.find(
+                query={
+                    "metadata.data._class": "orcaflex.job",
+                    "metadata.data.state.state": {"$in": includes},
+                    "metadata.data.batch": batch_name,
+                }
+            )
+            return jobs_q["data"]
+        elif exclude:
+            excludes = [e.value for e in exclude]
+            jobs_q = self.set.find(
+                query={
+                    "metadata.data._class": "orcaflex.job",
+                    "metadata.data.state.state": {"$nin": excludes},
+                    "metadata.data.batch": batch_name,
+                }
+            )
+            return jobs_q["data"]
+
     def save_job_videos(self, job, save_dir, case_name=""):
         if not isinstance(job, Set):
             job = self.set.get(job)
