@@ -17,6 +17,7 @@ processing of the simulation.
 """
 import ctypes as ct
 from dataclasses import dataclass, field, asdict
+from enum import Enum
 from typing import List, Mapping, Any, Tuple, Sequence
 
 import OrcFxAPI
@@ -67,6 +68,29 @@ class OrcaFlexJobOptions:
     update_interval: int = 5
 
 
+class JobState(Enum):
+    NEW = "New"  # When a job has been created
+    QUEUED = "Queued"  # When the job has been added to the queue
+    PRE_PROCESSING = "Pre-processing"  # The job has been loaded by a bot
+    PROCESSING = "Processing"  # The job is about to be run bot
+    LOADING_MODEL_DATA = "Loading model data"  # The model data is about to be loaded
+    MODEL_DATA_LOADED = "Model data loaded"  # The model data has loaded
+    RUNNING_STATICS = "Running statics"  # Trying to find a static solution
+    STATICS_FAILED = "Statics failed"  # Couldn't find a static solution
+    RUNNING_DYNAMICS = "Running dynamics"  # Running simulation dynamics
+    SAVING_SIMULATION = "Saving simulation"  # Saving the simulation data to qalx
+    SIMULATION_SAVED = "Simulation saved"  # Simulation data saved
+    EXTRACTING_RESULTS = "Extracting results"  # Extracting results
+    RESULTS_EXTRACTED = "Results extracted"  # All results extracted
+    EXTRACTING_MODEL_VIEWS = "Extracting model views"  # Extracting model views
+    MODEL_VIEWS_EXTRACTED = "Model views extracted"  # All model views extracted
+    EXTRACTING_MODEL_VIDEOS = "Extracting model videos"  # Extracting videos
+    MODEL_VIDEOS_EXTRACTED = "Model videos extracted"  # Videos extracted
+    SIMULATION_UNSTABLE = "Simulation unstable"  # Simulation was unstable
+    ERROR = "Error"  # There was an error
+    USER_CANCELLED = "User cancelled"  # A user cancelled the job
+
+
 @dataclass
 class OrcaFlexJobState:
     """the current state of an OrcaFlex job
@@ -76,7 +100,7 @@ class OrcaFlexJobState:
     :param error [str]: error text is the state is rror (default=None)
     """
 
-    state: str = field(default="New")
+    state: str = field(default=JobState.NEW.value)
     info: str = None
     error: str = None
 
