@@ -231,13 +231,7 @@ class ModelWithLicence:
     There are other options to control how the wait between attempts will spread.
     """
 
-    __slots__ = (
-        "max_attempts",
-        "wait_lower",
-        "wait_upper",
-        "spreading",
-        "_model",
-    )
+    __slots__ = ("max_attempts", "wait_lower", "wait_upper", "spreading", "_model")
 
     def __init__(
         self,
